import os
import pkg_resources
import sys

def try_install_pickle5():
    should_install_pickle5 = False
    try:
        version_info = pkg_resources.require("pickle5")
        version = tuple(int(n) for n in version_info[0].version.split("."))
        if version < (0, 0, 11):
            should_install_pickle5 = True
    except pkg_resources.DistributionNotFound:
        should_install_pickle5 = True
    if should_install_pickle5:
        print("Count not find pickle5 >= 0.0.11 which is required. Trying to install one from prebuilt wheels...")
        rv = os.system(f'{sys.executable} -m pip install --no-index --find-links=https://github.com/suquark/pickle5-backport/releases/tag/0.0.11 pickle5')
        if rv != 0:
            raise Exception("Failed to install pickle5.")



from setuptools import setup, find_packages
from setuptools.command.install import install
import setuptools

from pickle5_wheels_helper import try_install_pickle5


class PostInstallCommand(install):
    def run(self):
        install.run(self)
        try_install_pickle5()
        try:
            import pickle5
        except Exception as e:
            raise Exception("pickle5 setup failed!") from e


setup(
    name="pickle5-wheels-helper",
    version="0.0.6",
    author="Siyuan Zhuang",
    author_email="suquark@gmail.com",
    description="Helper package for installing pickle5 wheels",
    url="https://github.com/suquark/pickle5-wheels-helper",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license="Apache 2.0",
    cmdclass={"install": PostInstallCommand},
)
